==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/order/shipping_status.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	shipping_status.lang.inc.php 2018-05-07
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array(
	'BUTTON_CONFIG_SHIPPING'                        => 'Lieferstatus Konfigurieren',
	'BUTTON_INSERT_SHIPPING'                        => 'Lieferstatus Einfügen',
	'ERROR_REMOVE_DEFAULT_SHIPPING_STATUS'          => 'Fehler: Der Standard-Lieferstatus kann nicht gelöscht werden. Bitte definieren Sie einen neuen Standard-Lieferstatus und wiederholen Sie den Vorgang.',
	'ERROR_STATUS_USED_IN_HISTORY'                  => 'Fehler: Dieser Lieferstatus wird zur Zeit noch für Artikel verwendet.',
	'ERROR_STATUS_USED_IN_ORDERS'                   => 'Fehler: Dieser Lieferstatus wird zur Zeit noch für Artikel verwendet.',
	'HEADING_CONFIG_SHIPPING'                       => 'Lieferstatus Konfigurieren',
	'HEADING_TITLE'                                 => 'Lieferstatus',
	'TABLE_HEADING_ACTION'                          => 'Aktion',
	'TABLE_HEADING_SHIPPING_STATUS'                 => 'Lieferstatus',
	'TABLE_HEADING_SHIPPING_TIME'                   => 'Lieferzeit',
	'TEXT_ACTIVATE_SHIPPING_STATUS'                 => 'Lieferstatusanzeige aktivieren:',
	'TEXT_CONFIG_SHIPPING'                          => 'Lieferstatus automatisch aktualisieren:',
	'TEXT_INFO_CANT_DELETE'                         => 'Dieser Lieferstatus wird von einigen Artikeln noch verwendet und kann daher nicht gelöscht werden.',
	'TEXT_INFO_DELETE_INTRO'                        => 'Sind Sie sicher, dass Sie diesen Lieferstatus löschen möchten?',
	'TEXT_INFO_EDIT_INTRO'                          => 'Bitte führen Sie notwendige Änderungen durch.',
	'TEXT_INFO_HEADING_DELETE_SHIPPING_STATUS'      => 'Lieferstatus löschen',
	'TEXT_INFO_HEADING_EDIT_SHIPPING_STATUS'        => 'Lieferstatus bearbeiten',
	'TEXT_INFO_HEADING_NEW_SHIPPING_STATUS'         => 'Neuer Lieferstatus',
	'TEXT_INFO_INSERT_INTRO'                        => 'Bitte geben Sie den neuen Lieferstatus mit allen relevanten Daten ein.',
	'TEXT_INFO_SHIPPING_STATUS_DAYS'                => 'Anzahl Wochentage:',
	'TEXT_INFO_SHIPPING_STATUS_GOOGLE_AVAILABILITY' => 'Diesen Lieferstatus mit folgender Google-Shopping-Verfügbarkeit verknüpfen:',
	'TEXT_INFO_SHIPPING_STATUS_IMAGE'               => 'Bild:',
	'TEXT_INFO_SHIPPING_STATUS_INFO_LINK_ACTIVE'    => '"Ausland abweichend"-Link anzeigen',
	'TEXT_INFO_SHIPPING_STATUS_NAME'                => 'Lieferstatus:',
	'TEXT_INFO_SHIPPING_STATUS_QUANTITY'            => 'Oberer Schwellenwert:',
	'TEXT_INPUT_SHIPPING_STATUS_QUANTITY'           => 'Geben Sie in dieses Feld den oberen Schwellenwert (Anzahl Artikel) ein, ab dem dieser Lieferstatus automatisch gesetzt wird. Der Lieferstatus wird nur bei Bestellungen über den Shop aktualisiert.<br /><br />Für den Lieferstatus mit der kürzesten Lieferzeit, also der größten Lagermenge, geben Sie als Schwellenwert 999999 an.',
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/order/shipping_status.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	shipping_status.lang.inc.php 2018-05-07
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array(
	'BUTTON_CONFIG_SHIPPING'                        => 'Lieferstatus Konfigurieren',
	'BUTTON_INSERT_SHIPPING'                        => 'Lieferstatus Einfügen',
	'ERROR_REMOVE_DEFAULT_SHIPPING_STATUS'          => 'Fehler: Der Standard-Lieferstatus kann nicht gelöscht werden. Bitte definiere einen neuen Standard-Lieferstatus und wiederhole den Vorgang.',
	'ERROR_STATUS_USED_IN_HISTORY'                  => 'Fehler: Dieser Lieferstatus wird zur Zeit noch für Artikel verwendet.',
	'ERROR_STATUS_USED_IN_ORDERS'                   => 'Fehler: Dieser Lieferstatus wird zur Zeit noch für Artikel verwendet.',
	'HEADING_CONFIG_SHIPPING'                       => 'Lieferstatus Konfigurieren',
	'HEADING_TITLE'                                 => 'Lieferstatus',
	'TABLE_HEADING_ACTION'                          => 'Aktion',
	'TABLE_HEADING_SHIPPING_STATUS'                 => 'Lieferstatus',
	'TABLE_HEADING_SHIPPING_TIME'                   => 'Lieferzeit',
	'TEXT_ACTIVATE_SHIPPING_STATUS'                 => 'Lieferstatusanzeige aktivieren:',
	'TEXT_CONFIG_SHIPPING'                          => 'Lieferstatus automatisch aktualisieren:',
	'TEXT_INFO_CANT_DELETE'                         => 'Dieser Lieferstatus wird von einigen Artikeln noch verwendet und kann daher nicht gelöscht werden.',
	'TEXT_INFO_DELETE_INTRO'                        => 'Bist du sicher, dass du diesen Lieferstatus löschen möchtest?',
	'TEXT_INFO_EDIT_INTRO'                          => 'Bitte führe notwendige Änderungen durch.',
	'TEXT_INFO_HEADING_DELETE_SHIPPING_STATUS'      => 'Lieferstatus löschen',
	'TEXT_INFO_HEADING_EDIT_SHIPPING_STATUS'        => 'Lieferstatus bearbeiten',
	'TEXT_INFO_HEADING_NEW_SHIPPING_STATUS'         => 'Neuer Lieferstatus',
	'TEXT_INFO_INSERT_INTRO'                        => 'Bitte gib den neuen Lieferstatus mit allen relevanten Daten ein.',
	'TEXT_INFO_SHIPPING_STATUS_DAYS'                => 'Anzahl Wochentage:',
	'TEXT_INFO_SHIPPING_STATUS_GOOGLE_AVAILABILITY' => 'Diesen Lieferstatus mit folgender Google-Shopping-Verfügbarkeit verknüpfen:',
	'TEXT_INFO_SHIPPING_STATUS_IMAGE'               => 'Bild:',
	'TEXT_INFO_SHIPPING_STATUS_INFO_LINK_ACTIVE'    => '"Ausland abweichend"-Link anzeigen',
	'TEXT_INFO_SHIPPING_STATUS_NAME'                => 'Lieferstatus:',
	'TEXT_INFO_SHIPPING_STATUS_QUANTITY'            => 'Oberer Schwellenwert:',
	'TEXT_INPUT_SHIPPING_STATUS_QUANTITY'           => 'Gib in dieses Feld den oberen Schwellenwert (Anzahl Artikel) ein, ab dem dieser Lieferstatus automatisch gesetzt wird. Der Lieferstatus wird nur bei Bestellungen über den Shop aktualisiert.<br /><br />Für den Lieferstatus mit der kürzesten Lieferzeit, also der größten Lagermenge, gib als Schwellenwert 999999 an.',
);
